# Django Direct Upload files to S3


# dj_upload2s3


## Usage

Add **dj\_upload2s3** to **INSTALLED\_APPS**

## TODO
- Add polyfills
- README
- Clean Code

## Credits

- Alexandre Busquets Triola



## License

The MIT License (MIT). Please see [License File](LICENSE.md) for more information.
